@@ -2,12 +2,13 @@
 
 import requests
 import grequests
-import uuid
 import os
 import urlparse
 import json
 import gevent
+import copy
 from gevent.pool import Pool
+from collections import OrderedDict
 
 from .patterns import Regex
 from .responses import ( DoneLoad, DoneFind, Wait, MissingTags,
@@ -16,6 +17,8 @@ from .templates import Substitution, InheritedDict
 from .errors import InvalidInstructionError, SchemeSecurityError, PatternError
 
 CURDIR = os.getcwd()
+FILE_CACHE = OrderedDict()
+MAX_FILE_CACHE_SIZE = 50
 
 class Request(object):
 
@@ -63,7 +66,6 @@ class Request(object):
 class Scraper(object):
 
     def __init__(self, session=None, force_all=False, concurrency=5):
-        self._file_cache = dict()
         self._pool = Pool(concurrency)
 
         if session is None:
@@ -93,12 +95,14 @@ class Scraper(object):
                 resolved_uri_str = urlparse.urlunsplit(resolved_uri)
 
                 # Use our file cache if we can
-                instruction = self._file_cache.get(resolved_uri_str)
+                instruction = copy.deepcopy(FILE_CACHE.get(resolved_uri_str))
 
                 # Otherwise, load and save in the cache
                 if instruction is None:
                     instruction = json.load(open(resolved_uri_str))
-                    self._file_cache[resolved_uri_str] = instruction
+                    FILE_CACHE[resolved_uri_str] = copy.deepcopy(instruction)
+                    if len(FILE_CACHE) > MAX_FILE_CACHE_SIZE:
+                        FILE_CACHE.popitem(last=False)
 
             else:
                 raise InvalidInstructionError("Reference to unsupported scheme '%s'" % (
